aboutsummaryrefslogtreecommitdiff
path: root/makeBoundary.py
diff options
context:
space:
mode:
Diffstat (limited to 'makeBoundary.py')
-rwxr-xr-xmakeBoundary.py7
1 files changed, 5 insertions, 2 deletions
diff --git a/makeBoundary.py b/makeBoundary.py
index 19ba37e..86b2955 100755
--- a/makeBoundary.py
+++ b/makeBoundary.py
@@ -226,8 +226,11 @@ print(total_flow)
ind_p = bisect.bisect(total_flow, target_flow)
print(ind_p)
-# find insertion point for target flow value
-ind_q = bisect.bisect(Q_i_west, target_flow_west)
+# calculate target flow in part-filled panel:
+panel_target_flow = target_flow - total_flow[ind_p-1]
+
+# find insertion point for target flow value:
+ind_q = bisect.bisect(Q_i[panel[ind_p]], panel_target_flow)
print(ind_q)
# find height at target flow by linear interpolation